@@ -1,3 +1,3 @@
 from nlp_tools.processors.class_processor import ClassificationProcessor
 from nlp_tools.processors.sequence_processor import SequenceProcessor
-from nlp_tools.processors.ner_label_processor import NerLabelProcessor
+from nlp_tools.processors.dialogue_sequence_processor import DialogueSequenceProcessor
